mysql.exceptions.map

Package mysql :: Package exceptions :: Module map |
[hide private]
[frames] | no frames]

# Module map

Mapping of MySQL internal error codes to exception objects.

This module should not be needed by end-user code, it is mainly for the internals of this library.

Functions | [hide private]
`` | raise_error(...) Raise a MySQL exception.

Variables | [hide private]
`` | __version__ = `'$Revision: 1.6 $'`
`` | _errno_map = `{2048L: <class mysql.exceptions.client.Invalid_Conn_...`

Function Details | [hide private]

### raise_error(...) |
Raise a MySQL exception. Parameters: `errno` - The error number. `err_str` - The error string.

Variables Details | [hide private]

    ### __version__ Value:
        '$Revision: 1.6 $'

    ### _errno_map Value:
        {1000L: <class mysql.exceptions.server.Hashchk at 0x852941c>,
         1001L: <class mysql.exceptions.server.Nisamchk at 0x852944c>,
         2048L: <class mysql.exceptions.client.Invalid_Conn_Handle at 0x84910e
        c>,
         2049L: <class mysql.exceptions.client.Secure_Auth at 0x849111c>,
         2050L: <class mysql.exceptions.client.Fetch_Canceled at 0x849114c>,
         2051L: <class mysql.exceptions.client.No_Data at 0x849117c>,
         2052L: <class mysql.exceptions.client.No_Stmt_Metadata at 0x84911ac>,
        ...